#!/usr/bin/env bash


function miner_ver() {
  local MINER_VER=$TT_MINER_VER
  [[ -z $MINER_VER ]] && MINER_VER=$MINER_LATEST_VER
  echo $MINER_VER
}


function miner_config_echo() {
  local MINER_VER=`miner_ver`
  miner_echo_config_file "/hive/miners/$MINER_NAME/$MINER_VER/miner.conf"
}


function miner_config_gen() {
  local MINER_CONFIG="$MINER_DIR/$MINER_VER/miner.conf"
  mkfile_from_symlink $MINER_CONFIG

  echo "-b 127.0.0.1:$MINER_API_PORT" > $MINER_CONFIG

  [[ ! -z $TT_MINER_USER_CONFIG ]] && echo "$TT_MINER_USER_CONFIG" >> $MINER_CONFIG

  t_algo=$TT_MINER_ALGO
  if [[ $t_algo =~ ([^[:space:]]+):([^[:space:]]+) ]]; then
    param=${BASH_REMATCH[1]}
    algo=${BASH_REMATCH[2]}
    if [[ $param == 'Algo' ]]; then
      echo "-a $algo" >> $MINER_CONFIG
    else
      echo "-c $algo" >> $MINER_CONFIG
    fi
  elif [[ $t_algo =~ "progpowepic" ]]; then
    echo "-c EPIC" >> $MINER_CONFIG
  else
    echo "-a $TT_MINER_ALGO" >> $MINER_CONFIG
  fi

  t_url=$(head -n 1 <<< "$TT_MINER_URL")

# Setup pool/user for ProgPow like pools
  if [[ $t_algo =~ "progpow" ]]; then
    if [[ $t_url == *://* ]]; then
      if [[ $t_url =~ ([^[:space:]]+)://([^[:space:]]+) ]]; then
        protocol=${BASH_REMATCH[1]}
        url=${BASH_REMATCH[2]}
      fi
    else
      protocol=
      url="$t_url"
    fi
    [[ -z $protocol ]] && PP_PROTO="" || PP_PROTO="${protocol}://"
    PP_POOL=$url
    PP_WAL=$TT_MINER_TEMPLATE
    [[ -z $TT_MINER_PASS ]] && PP_PASS="" || PP_PASS=":$TT_MINER_PASS"
    echo "-P ${PP_PROTO}${PP_WAL}${PP_PASS}@${PP_POOL}" >> $MINER_CONFIG
# Other coins
  else
    echo "-u $TT_MINER_TEMPLATE" >> $MINER_CONFIG

    [[ ! -z $TT_MINER_PASS ]] && echo "-p $TT_MINER_PASS" >> $MINER_CONFIG

    if [[ $t_url == *://* ]]; then
      if [[ $t_url =~ ([^[:space:]]+)://([^[:space:]]+) ]]; then
        protocol=${BASH_REMATCH[1]}
        url=${BASH_REMATCH[2]}
        if [[ ! $protocol =~ ssl ]]; then
          protocol="ssl"
        fi
        t_url="${protocol}://${url}"
      else
        echo -e "${YELLOW} Pool address parsing error${NOCOLOR}"
        return 1
      fi
    else
      t_url="$t_url"
    fi

    echo "-o $t_url" >> $MINER_CONFIG
  fi
  
# Dual mining configuration: not implemented yet
  if [[ -n $TT_MINER_ALGO2 ]]; then
    t_algo=$TT_MINER_ALGO2
    if [[ $t_algo =~ ([^[:space:]]+):([^[:space:]]+) ]]; then
      param=${BASH_REMATCH[1]}
      algo=${BASH_REMATCH[2]}
      if [[ $param == 'Algo' ]]; then
        echo "-aalt $algo" >> $MINER_CONFIG
      else
        echo "-calt $algo" >> $MINER_CONFIG
      fi
    else
      echo -e "${YELLOW} Algo2 parsing error${NOCOLOR}"
      return 1
    fi

    echo "-ualt $TT_MINER_TEMPLATE2" >> $MINER_CONFIG

    [[ ! -z $TT_MINER_PASS ]] && echo "-palt $TT_MINER_PASS2" >> $MINER_CONFIG

    t_url=$(head -n 1 <<< "$TT_MINER_URL2")
    if [[ $TT_MINER_TLS2 -eq 1 ]]; then
      if [[ $t_url == *://* ]]; then
        if [[ $t_url =~ ([^[:space:]]+)://([^[:space:]]+) ]]; then
          protocol=${BASH_REMATCH[1]}
          url=${BASH_REMATCH[2]}
          if [[ ! $protocol =~ ssl ]]; then
            protocol="ssl"
          fi
          t_url="${protocol}://${url}"
        else
          echo -e "${YELLOW} Pool address parsing error${NOCOLOR}"
          return 1
        fi
      else
        t_url="ssl://$t_url"
      fi
    fi
    echo "-oalt $t_url" >> $MINER_CONFIG
  fi
}
